summaryrefslogtreecommitdiff
path: root/nuttx/graphics/nxtk/nxtk_movetoolbar.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-04 12:57:22 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-04 12:57:22 +0000
commit05d31bd06816565ec8af26885ecaa26851851e18 (patch)
treee9267ad7e7f24d444cb8c8fd290e24e6c1f88c99 /nuttx/graphics/nxtk/nxtk_movetoolbar.c
parent01fab0c78eeef5461a896847f05caec51d26050f (diff)
downloadpx4-nuttx-05d31bd06816565ec8af26885ecaa26851851e18.tar.gz
px4-nuttx-05d31bd06816565ec8af26885ecaa26851851e18.tar.bz2
px4-nuttx-05d31bd06816565ec8af26885ecaa26851851e18.zip
Removed superfluous toolbar handle
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1412 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/graphics/nxtk/nxtk_movetoolbar.c')
-rw-r--r--nuttx/graphics/nxtk/nxtk_movetoolbar.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/nuttx/graphics/nxtk/nxtk_movetoolbar.c b/nuttx/graphics/nxtk/nxtk_movetoolbar.c
index 78a20b54e..6e464c375 100644
--- a/nuttx/graphics/nxtk/nxtk_movetoolbar.c
+++ b/nuttx/graphics/nxtk/nxtk_movetoolbar.c
@@ -81,8 +81,9 @@
* Move a rectangular region within the toolbar sub-window of a framed window
*
* Input Parameters:
* htb - The toolbar sub-window within which the move is to be done.
* This must have been previously created by nxtk_openwindow().
* rect - Describes the rectangular region relative to the toolbar
* sub-window to move
* offset - The offset to move the region
@@ -92,15 +93,15 @@
*
****************************************************************************/
-int nxtk_movetoolbar(NXTKTOOLBAR htb, FAR const struct nxgl_rect_s *rect,
+int nxtk_movetoolbar(NXTKWINDOW hfwnd, FAR const struct nxgl_rect_s *rect,
FAR const struct nxgl_point_s *offset)
{
- FAR struct nxtk_framedwindow_s *fwnd = (FAR struct nxtk_framedwindow_s *)htb;
+ FAR struct nxtk_framedwindow_s *fwnd = (FAR struct nxtk_framedwindow_s *)hfwnd;
struct nxgl_rect_s srcrect;
struct nxgl_point_s clipoffset;
#ifdef CONFIG_DEBUG
- if (!htb || !rect || !offset)
+ if (!hfwnd || !rect || !offset)
{
errno = EINVAL;
return ERROR;
@@ -115,5 +116,5 @@ int nxtk_movetoolbar(NXTKTOOLBAR htb, FAR const struct nxgl_rect_s *rect,
/* Then move it within the toolbar window */
- return nx_move((NXTKTOOLBAR)htb, &srcrect, &clipoffset);
+ return nx_move((NXWINDOW)hfwnd, &srcrect, &clipoffset);
}
@@ -81,8 +81,9 @@
*
* Input Parameters:
- * htb - The toolbar sub-window within which the move is to be done.
- * This must have been previously created by nxtk_openwindow().
+ * hfwnd - The sub-window containing the toolbar within which the move is
+ * to be done. This must have been previously created by
+ * nxtk_openwindow().
* rect - Describes the rectangular region relative to the toolbar
* sub-window to move